@@ -86,7 +86,7 @@
 #define BALOO_CORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef BALOO_CORE_NO_DEPRECATED
-#  define BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54500
+#  define BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54a00
 #endif
 #ifdef BALOO_CORE_NO_DEPRECATED_WARNINGS
 #  define BALOO_CORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define BALOO_CORE_DEPRECATED_WARNINGS_SINCE BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define BALOO_CORE_DEPRECATED_WARNINGS_SINCE 0x54500
+#    define BALOO_CORE_DEPRECATED_WARNINGS_SINCE 0x54a00
 #  endif
 #endif
 
@@ -123,5 +123,6 @@
 #endif
 #define BALOO_CORE_DEPRECATED_VERSION_5(minor, text)      BALOO_CORE_DEPRECATED_VERSION_5_##minor(text)
 #define BALOO_CORE_DEPRECATED_VERSION(major, minor, text) BALOO_CORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define BALOO_CORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) BALOO_CORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* BALOO_CORE_EXPORT_H */
